geomPCA: Geometric Principal Component Analysis

Description Usage Arguments Value Examples

View source: R/geomPCA.R

Description

Computes the principal component (PC) scores from the geometric principal component analysis on probability density functions.

Usage

1
geomPCA(x, perc.var = 99, m = 512)

Arguments

x

a list with each entry as a vector of values required to compute the probability density function for that case/subject

perc.var

percentage variance explained by PCs (between 0 to 100)

m

number of equally spaced points at which the densities are to be estimated

Value

pcScores principal component scores; a matrix of size nxp, where p is the number of PCs included

Examples

1
2
x = lapply(1:10, function(i) rnorm(100))
PCScores = geomPCA(x)

shariq-mohammed/RADIOHEAD documentation built on Dec. 10, 2020, 10:19 a.m.