Description Usage Arguments Value Examples
Computes the principal component (PC) scores from the geometric principal component analysis on probability density functions.
1 | geomPCA(x, perc.var = 99, m = 512)
|
x |
a list with each entry as a vector of values required to compute the probability density function for that case/subject |
perc.var |
percentage variance explained by PCs (between 0 to 100) |
m |
number of equally spaced points at which the densities are to be estimated |
pcScores principal component scores; a matrix of size nxp, where p is the number of PCs included
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.