Description Usage Arguments Value Examples
Gibbs sampling algorithm for the estiamtion of the model with group spike-and-slab prior
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 |
y |
response for n subjects |
X |
predictors - dimension n subjects x L predictors |
g_id |
numeric vector indicating group membership in the predictors. Contains values 1,…,g if the predictors belong to g groups |
beta_init |
initial values for β. Defaults to 0. |
zeta_init |
initial values for ζ. Defaults to random generation from Ber(0.5). |
w_init |
initial value for w - the complexity parameter. Defaults to proportion of 1s in zeta_init. |
nusq_init |
initial values for ν^2. Defaults to 1. |
sigsq_init |
initial values for \sig^2. Defaults to 1. |
v0 |
hyperparameter v0. Defaults to 0.005. |
a1 |
hyperparameter a1. Defaults to 0.001. |
a2 |
hyperparameter a2. Defaults to 0.001. |
c1 |
hyperparameter c1. Defaults to 0.001. |
c2 |
hyperparameter c2. Defaults to 0.001. |
Nmcmc |
number of MCMC samples to generate. Defaults to 5000. |
ind |
indices of MCMC samples to use after burnin and thinning. Defaults to 1 to Nmcmc. |
zeta: MCMC samples of ζ - dimension N samples x g groups
b: MCMC samples of β - dimension N samples x L predictors
x_cnames: column names from the predictor matrix
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.